/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { DropZoneService } from './dropzone.service';
import { UploadComponent } from './upload.component';
import { FileSelectComponent } from './fileselect.component';
import * as i0 from "@angular/core";
/**
 * Represents the [Kendo UI UploadDropZone directive for Angular]({% slug overview_upload %}).
 * Use this directive to create external drop zones for Upload and FileSelect components.
 *
 * @example
 * ```html
 * <div kendoUploadDropZone="upload1">Drop files here</div>
 * <kendo-upload [saveUrl]="uploadSaveUrl" zoneId="upload1"></kendo-upload>
 * ```
 */
export declare class UploadDropZoneDirective {
    private dropZoneService;
    /**
     * The id of the drop zone to associate with an existing Upload component.
     */
    zoneId: string;
    /**
     * The id of the drop zone to associate with an existing FileSelect component.
     */
    fileSelectZoneId: string;
    constructor(dropZoneService: DropZoneService);
    /**
     * @hidden
     */
    onElementDragEnter(): boolean;
    /**
     * @hidden
     */
    onElementDragOver(): boolean;
    /**
     * @hidden
     */
    onDropListener(event: any): boolean;
    /**
     * @hidden
     */
    get componentInstance(): Array<UploadComponent | FileSelectComponent>;
    static ɵfac: i0.ɵɵFactoryDeclaration<UploadDropZoneDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UploadDropZoneDirective, "[kendoUploadDropZone], [kendoFileSelectDropZone]", never, { "zoneId": { "alias": "kendoUploadDropZone"; "required": false; }; "fileSelectZoneId": { "alias": "kendoFileSelectDropZone"; "required": false; }; }, {}, never, never, true, never>;
}
