/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, Renderer2 } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { DropZoneBase } from './dropzone-base';
import { SVGIcon } from '@progress/kendo-svg-icons';
import * as i0 from "@angular/core";
/**
 * Represents the [Kendo UI UploadDropZone component for Angular]({% slug overview_upload %}).
 *
 * @example
 * ```html
 * <kendo-uploaddropzone zoneId="upload1">
 *   Drop files here to upload
 * </kendo-uploaddropzone>
 * <kendo-upload [saveUrl]="uploadSaveUrl" zoneId="upload1"></kendo-upload>
 * ```
 *
 * @remarks
 * Supported children components are: {@link CustomMessagesComponent}
 */
export declare class UploadDropZoneComponent extends DropZoneBase {
    private localization;
    hostClass: boolean;
    get dirAttribute(): string;
    /**
     * Specifies the id of the component.
     * Use this id to associate the DropZone with an existing Upload or FileSelect component.
     */
    zoneId: string;
    /**
     * Specifies the name for an existing icon in a Kendo UI theme.
     * The icon renders inside the DropZone.
     */
    icon: string;
    /**
     * Specifies a CSS class or multiple classes separated by spaces which apply to a span element.
     * Use this property to apply custom icons.
     */
    iconClass: string;
    /**
     * Specifies an SVGIcon to render inside the DropZone.
     * The input accepts either an [existing Kendo SVG icon](slug:svgicon_list) or a custom one.
     */
    set svgIcon(icon: SVGIcon);
    get svgIcon(): SVGIcon;
    private direction;
    private localizationChangeSubscription;
    private _svgIcon;
    constructor(element: ElementRef, renderer: Renderer2, localization: LocalizationService);
    /**
     * @hidden
     */
    textFor(key: string): string;
    /**
     * @hidden
     */
    get iconClasses(): string;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UploadDropZoneComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UploadDropZoneComponent, "kendo-uploaddropzone", ["kendoUploadDropZone"], { "zoneId": { "alias": "zoneId"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; "iconClass": { "alias": "iconClass"; "required": false; }; "svgIcon": { "alias": "svgIcon"; "required": false; }; }, {}, never, ["*"], true, never>;
}
