/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { UploadDropZoneDirective } from "./dropzone-external.directive";
import { UploadDropZoneComponent } from "./dropzone.component";
import { FileSelectComponent } from "./fileselect.component";
import { CustomMessagesComponent } from "./localization/custom-messages.component";
import { UploadActionButtonsComponent } from "./rendering/upload-action-buttons.component";
import { UploadStatusTotalComponent } from "./rendering/upload-status-total.component";
import { FileInfoTemplateDirective } from "./templates/file-info-template.directive";
import { FileTemplateDirective } from "./templates/file-template.directive";
import { UploadComponent } from "./upload.component";
/**
 * Use the `KENDO_FILESELECT` utility array to add all FileSelect-related components and directives to a standalone Angular component.
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 * import { KENDO_FILESELECT } from '@progress/kendo-angular-upload';
 *
 * @Component({
 *   selector: 'my-app',
 *   standalone: true,
 *   imports: [KENDO_FILESELECT],
 *   template: `<kendo-fileselect></kendo-fileselect>`
 * })
 * export class AppComponent {}
 * ```
 */
export const KENDO_FILESELECT = [
    FileSelectComponent,
    FileTemplateDirective,
    FileInfoTemplateDirective,
    CustomMessagesComponent,
    UploadDropZoneDirective,
    UploadDropZoneComponent
];
/**
 * Use the `KENDO_UPLOAD` utility array to add all Upload-related components and directives to a standalone Angular component.
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 * import { KENDO_UPLOAD } from '@progress/kendo-angular-upload';
 *
 * @Component({
 *   selector: 'my-app',
 *   standalone: true,
 *   imports: [KENDO_UPLOAD],
 *   template: `<kendo-upload></kendo-upload>`
 * })
 * export class AppComponent {}
 * ```
 */
export const KENDO_UPLOAD = [
    UploadComponent,
    UploadActionButtonsComponent,
    UploadStatusTotalComponent,
    FileTemplateDirective,
    FileInfoTemplateDirective,
    CustomMessagesComponent,
    UploadDropZoneDirective,
    UploadDropZoneComponent
];
/**
 * Use the `KENDO_UPLOADS` utility array to add all `@progress/kendo-angular-upload`-related components and directives to a standalone Angular component.
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 * import { KENDO_UPLOADS } from '@progress/kendo-angular-upload';
 *
 * @Component({
 *   selector: 'my-app',
 *   standalone: true,
 *   imports: [KENDO_UPLOADS],
 *   template: `
 *      <kendo-upload></kendo-upload>
 *      <kendo-fileselect></kendo-fileselect>
 *   `
 * })
 * export class AppComponent {}
 * ```
 */
export const KENDO_UPLOADS = [
    ...KENDO_FILESELECT,
    ...KENDO_UPLOAD
];
