/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Arguments for the `error` event. The `error` event fires when
 * an `upload` or `remove` operation fails.
 *
 * ```typescript
 * @Component({
 *    template: `
 *    <kendo-upload (error)="errorEventHandler($event)"></kendo-upload>
 *    `
 *  })
 *  export class UploadComponent {
 *   public errorEventHandler(e: ErrorEvent) {
 *      console.log('An error occurred');
 *    }
 * }
 * ```
 */
export class ErrorEvent {
    /**
     * The array of files that failed to be uploaded or removed.
     */
    files;
    /**
     * The operation type that failed (`upload` or `remove`).
     */
    operation;
    /**
     * The HTTP response returned by the server containing error details.
     */
    response;
    /**
     * @hidden
     * Constructs the event arguments for the `error` event.
     *
     * @param files - The list of the files that failed to be uploaded or removed.
     * @param operation - The operation type (`upload` or `remove`).
     * @param response - The response object returned by the server.
     */
    constructor(files, operation, response) {
        this.files = files;
        this.operation = operation;
        this.response = response;
    }
}
