/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from './preventable-event';
/**
 * Arguments for the `select` event. The `select` event fires when
 * a file or multiple files are selected for upload. The event can be canceled to prevent selection.
 *
 * ```typescript
 *  @Component({
 *    template: `
 *    <kendo-upload (select)="selectEventHandler($event)"></kendo-upload>
 *    `
 *  })
 *  export class UploadComponent {
 *    public selectEventHandler(e: SelectEvent) {
 *      console.log('File selected');
 *    }
 *  }
 * ```
 */
export class SelectEvent extends PreventableEvent {
    /**
     * The files that are selected for upload.
     */
    files;
    /**
     * @hidden
     * Constructs the event arguments for the `select` event.
     * @param files - The list of the selected files.
     */
    constructor(files) {
        super();
        this.files = files;
    }
}
