/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Arguments for the `uploadprogress` event. The `uploadprogress` event
 * fires when you upload files.
 *
 * ```typescript
 *  @Component({
 *    template: `
 *    <kendo-upload (uploadProgress)="uploadProgressEventHandler($event)"></kendo-upload>
 *    `
 *  })
 *  export class UploadComponent {
 *    public uploadProgressEventHandler(e: UploadProgressEvent) {
 *      console.log(e.files[0].name + ' is ' + e.percentComplete + ' uploaded');
 *    }
 *  }
 * ```
 */
export class UploadProgressEvent {
    /**
     * The files that you are currently uploading.
     */
    files;
    /**
     * The upload progress as a percentage from 0 to 100.
     */
    percentComplete;
    /**
     * @hidden
     * Constructs the event arguments for the `uploadprogress` event.
     * @param files - The list of files that are being uploaded.
     * @param percentComplete - The portion that has been uploaded.
     */
    constructor(files, percentComplete) {
        this.files = files;
        this.percentComplete = percentComplete;
    }
}
