/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { FileInfo } from '../types';
/**
 * Arguments for the `cancel` event. The `cancel` event fires when
 * you cancel the upload of a file or batch of files.
 *
 * ```typescript
 * @Component({
 *    template: `
 *    <kendo-upload (cancel)="cancelEventHandler($event)"></kendo-upload>
 *    `
 *  })
 *  export class UploadComponent {
 *    public cancelEventHandler(e: CancelEvent) {
 *      console.log('Canceling file upload', e.files);
 *    }
 * }
 * ```
 */
export declare class CancelEvent {
    /**
     * The files that you canceled during the upload process.
     */
    files: Array<FileInfo>;
    /**
     * @hidden
     * Constructs the event arguments for the `cancel` event.
     * @param files - The list of the files that were going to be uploaded.
     */
    constructor(files: Array<FileInfo>);
}
