/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from './preventable-event';
/**
 * Arguments for the `clear` event. The `clear` event fires when
 * the **Clear** button is clicked and selected files are about to be cleared.
 *
 * ```typescript
 * @Component({
 *    template: `
 *    <kendo-upload (clear)="clearEventHandler($event)"></kendo-upload>
 *    `
 *  })
 *  export class UploadComponent {
 *    public clearEventHandler(e: ClearEvent) {
 *      console.log('Clearing the file upload');
 *    }
 * }
 * ```
 */
export declare class ClearEvent extends PreventableEvent {
    /**
     * @hidden
     * Constructs the event arguments for the `clear` event.
     */
    constructor();
}
