/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { HttpResponse } from '@angular/common/http';
import { FileInfo, OperationType } from '../types';
/**
 * Arguments for the `error` event. The `error` event fires when
 * an `upload` or `remove` operation fails.
 *
 * ```typescript
 * @Component({
 *    template: `
 *    <kendo-upload (error)="errorEventHandler($event)"></kendo-upload>
 *    `
 *  })
 *  export class UploadComponent {
 *   public errorEventHandler(e: ErrorEvent) {
 *      console.log('An error occurred');
 *    }
 * }
 * ```
 */
export declare class ErrorEvent {
    /**
     * The array of files that failed to be uploaded or removed.
     */
    files: Array<FileInfo>;
    /**
     * The operation type that failed (`upload` or `remove`).
     */
    operation: OperationType;
    /**
     * The HTTP response returned by the server containing error details.
     */
    response: HttpResponse<any>;
    /**
     * @hidden
     * Constructs the event arguments for the `error` event.
     *
     * @param files - The list of the files that failed to be uploaded or removed.
     * @param operation - The operation type (`upload` or `remove`).
     * @param response - The response object returned by the server.
     */
    constructor(files: Array<FileInfo>, operation: OperationType, response: HttpResponse<any>);
}
