/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { FileInfo } from '../types';
/**
 * Arguments for the `pause` event. The `pause` event fires when
 * you pause a file that is currently uploading.
 *
 * ```typescript
 *  @Component({
 *    template: `
 *    <kendo-upload
 *      [chunkable]="true"
 *      (pause)="pauseEventHandler($event)">
 *    </kendo-upload>
 *    `
 *  })
 *  export class UploadComponent {
 *    public pauseEventHandler(ev: PauseEvent) {
 *      console.log('File paused');
 *    }
 *  }
 * ```
 */
export declare class PauseEvent {
    /**
     * The file that you paused during the upload process.
     */
    file: FileInfo;
    /**
     * @hidden
     * Constructs the event arguments for the `pause` event.
     * @param file - The file that is going to be paused.
     */
    constructor(file: FileInfo);
}
