/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { HttpHeaders } from '@angular/common/http';
import { PreventableEvent } from './preventable-event';
import { FileInfo } from '../types';
/**
 * Arguments for the `remove` event. The `remove` event fires when you are about to remove an uploaded
 * or selected file. You can cancel this event to prevent removal.
 *
 * ```typescript
 *  @Component({
 *    template: `
 *    <kendo-upload (remove)="removeEventHandler($event)"></kendo-upload>
 *    `
 *  })
 *  export class UploadComponent {
 *    public removeEventHandler(e: RemoveEvent) {
 *      console.log('Removing a file');
 *    }
 *  }
 * ```
 */
export declare class RemoveEvent extends PreventableEvent {
    /**
     * An optional object that you send to the `remove` handler as key/value pairs.
     *
     */
    data: Object;
    /**
     * The files that you will remove from the server.
     */
    files: Array<FileInfo>;
    /**
     * The headers of the request.
     * You can use this to add custom headers to the remove request.
     */
    headers: HttpHeaders;
    /**
     * @hidden
     * Constructs the event arguments for the `remove` event.
     * @param files - The list of the files that will be removed.
     * @param headers - The headers of the request.
     */
    constructor(files: Array<FileInfo>, headers: HttpHeaders);
}
