/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { HttpResponse } from '@angular/common/http';
import { FileInfo, OperationType } from '../types';
import { PreventableEvent } from './preventable-event';
/**
 * Arguments for the `success` event. The `success` event fires when
 * you successfully upload or remove the selected files.
 *
 * ```typescript
 *  @Component({
 *    template: `
 *    <kendo-upload (success)="successEventHandler($event)"></kendo-upload>
 *    `
 *  })
 *  export class UploadComponent {
 *    public successEventHandler(e: SuccessEvent) {
 *      console.log('The ' + e.operation + ' was successful!');
 *    }
 *  }
 * ```
 */
export declare class SuccessEvent extends PreventableEvent {
    /**
     * The files that you successfully uploaded or removed.
     */
    files: Array<FileInfo>;
    /**
     * The operation type that succeeded (`upload` or `remove`).
     */
    operation: OperationType;
    /**
     * The HTTP response that the server returns to confirm success.
     */
    response: HttpResponse<any>;
    /**
     * @hidden
     * Constructs the event arguments for the `success` event.
     * @param files - The list of the files that were uploaded or removed.
     * @param operation - The operation type (`upload` or `remove`).
     * @param response - The response object returned by the server.
     */
    constructor(files: Array<FileInfo>, operation: OperationType, response: HttpResponse<any>);
}
